@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -37,6 +37,7 @@ import com.openexchange.java.Strings;
 import com.openexchange.log.LogProperties;
 import com.openexchange.mail.api.AuthType;
 import com.openexchange.mail.api.MailConfig;
+import com.openexchange.mailaccount.AccountNature;
 import com.openexchange.push.PushExceptionCodes;
 import com.openexchange.push.PushListenerService;
 import com.openexchange.push.PushManagerExtendedService;
@@ -294,7 +295,7 @@ public abstract class AbstractDovecotPushManagerService implements PushManagerEx
                 session = generateSessionFor(pushUser);
             }
 
-            if (AuthType.isOAuthType(MailConfig.getConfiguredAuthType(true, session)) && session.getParameter(Session.PARAM_OAUTH_ACCESS_TOKEN) == null) {
+            if (AuthType.isOAuthType(MailConfig.getConfiguredAuthTypeForMailAccess(AccountNature.PRIMARY, session)) && session.getParameter(Session.PARAM_OAUTH_ACCESS_TOKEN) == null) {
                 LOGGER.debug("Falling back to DoveAdm push registration context due to missing OAuth token in session");
                 return RegistrationContext.createDoveAdmClientContext(pushUser.getUserId(), pushUser.getContextId(), new ServiceLookupDoveAdmClientProvider(services));
             }
