@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -22,6 +22,7 @@
 package com.openexchange.push.dovecot;
 
 import static com.openexchange.java.Autoboxing.I;
+import java.util.Optional;
 import javax.mail.FolderClosedException;
 import javax.mail.MessagingException;
 import javax.mail.StoreClosedException;
@@ -105,7 +106,15 @@ public class DefaultRegistrationPerformer implements RegistrationPerformer {
             user = userService.getUser(userId, contextId);
         }
 
-        String login = MailConfig.getMailLogin(defaultMailAccount, user.getLoginInfo(), userId, contextId);
+        String login;
+        {
+            Session optionalSession = registrationContext.getSession();
+            if (optionalSession == null) {
+                login = MailConfig.getMailLogin(defaultMailAccount, user.getLoginInfo(), userId, contextId);
+            } else {
+                login = MailConfig.getLogin(defaultMailAccount, user.getLoginInfo(), userId, contextId, true, Optional.of(optionalSession));
+            }
+        }
         return doveAdmClient.checkUser(login, userId, contextId);
     }
 
