@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -88,7 +88,7 @@ public class DovecotPushListener extends AbstractDovecotPushListener implements
     }
 
     @Override
-    public synchronized String initateRegistration() throws OXException {
+    public synchronized String initateRegistration(boolean initiateLockRefresher) throws OXException {
         if (initialized) {
             // Already initialized
             return null;
@@ -124,15 +124,17 @@ public class DovecotPushListener extends AbstractDovecotPushListener implements
             initialized = true;
 
             // Schedule to refresh cluster lock
-            long delay = TIMEOUT_THRESHOLD_MILLIS;
-            refreshLockTask = timerService.scheduleAtFixedRate(this, delay, delay);
+            if (initiateLockRefresher) {
+                long delay = TIMEOUT_THRESHOLD_MILLIS;
+                refreshLockTask = timerService.scheduleAtFixedRate(this, delay, delay);
+            }
             return null;
         } catch (RuntimeException rte) {
             throw PushExceptionCodes.UNEXPECTED_ERROR.create(rte, rte.getMessage());
         } finally {
             if (scheduleRetry) {
                 long delay = 5000L;
-                retryTask = timerService.schedule(new RetryRunnable(logInfo, LOGGER), delay);
+                retryTask = timerService.schedule(new RetryRunnable(initiateLockRefresher, logInfo, LOGGER), delay);
             }
         }
     }
