@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -284,7 +284,7 @@ public class DovecotPushManagerService extends AbstractDovecotPushManagerService
                         DovecotPushListener listener = new DovecotPushListener(registrationContext, false, this, services);
                         listeners.put(key, listener);
                         removeListener = true;
-                        String reason = listener.initateRegistration();
+                        String reason = listener.initateRegistration(true);
                         if (null == reason) {
                             removeListener = false;
                             unlock = false;
@@ -330,6 +330,7 @@ public class DovecotPushManagerService extends AbstractDovecotPushManagerService
             } else {
                 LOGGER.info("Could not acquire lock to start Dovecot listener for user {} in context {} with session {} ({}) as there is already an associated listener", I(userId), I(contextId), session.getSessionID(), session.getClient());
             }
+            new DovecotPushListener(registrationContext, false, this, services).initateRegistration(false);
         }
 
         // No listener registered for given session
@@ -408,7 +409,7 @@ public class DovecotPushManagerService extends AbstractDovecotPushManagerService
                         DovecotPushListener listener = new DovecotPushListener(registrationContext, true, this, services);
                         listeners.put(key, listener);
                         removeListener = true;
-                        String reason = listener.initateRegistration();
+                        String reason = listener.initateRegistration(true);
                         if (null == reason) {
                             removeListener = false;
                             unlock = false;
@@ -428,7 +429,7 @@ public class DovecotPushManagerService extends AbstractDovecotPushManagerService
                         DovecotPushListener listener = new DovecotPushListener(registrationContext, true, this, services);
                         listeners.put(key, listener);
                         removeListener = true;
-                        String reason = listener.initateRegistration();
+                        String reason = listener.initateRegistration(true);
                         if (null == reason) {
                             removeListener = false;
                             unlock = false;
@@ -474,6 +475,7 @@ public class DovecotPushManagerService extends AbstractDovecotPushManagerService
             } else {
                 LOGGER.info("Could not acquire lock to start permanent Dovecot listener for user {} in context {} as there is already an associated listener", I(userId), I(contextId));
             }
+            new DovecotPushListener(registrationContext, true, this, services).initateRegistration(false);
         }
 
         // No listener registered for given session
