@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -56,7 +56,7 @@ public class StatelessDovecotPushListener extends AbstractDovecotPushListener {
     }
 
     @Override
-    public synchronized String initateRegistration() throws OXException {
+    public synchronized String initateRegistration(boolean initiateLockRefresher) throws OXException {
         if (false == registrationContext.hasWebMailAndIsActive()) {
             StringBuilder sb = new StringBuilder("Denied start of a ").append(permanent ? "permanent" : "session-bound").append(" push listener for user ").append(registrationContext.getUserId());
             sb.append(" in context ").append(registrationContext.getContextId()).append(": Missing \"webmail\" permission or user is disabled.");
@@ -94,7 +94,7 @@ public class StatelessDovecotPushListener extends AbstractDovecotPushListener {
                     throw ServiceExceptionCode.absentService(TimerService.class);
                 }
                 long delay = 5000L;
-                timerService.schedule(new RetryRunnable(logInfo, LOGGER), delay);
+                timerService.schedule(new RetryRunnable(initiateLockRefresher, logInfo, LOGGER), delay);
             }
         }
     }
