@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -90,7 +90,7 @@ public class StatelessDovecotPushManagerService extends AbstractDovecotPushManag
 
         RegistrationContext registrationContext = getRegistrationContext(session);
         StatelessDovecotPushListener listener = new StatelessDovecotPushListener(registrationContext, false, services);
-        String reason = listener.initateRegistration();
+        String reason = listener.initateRegistration(true);
         if (null == reason) {
             if (LOGGER.isDebugEnabled()) {
                 LOGGER.info("Started Dovecot listener for user {} in context {} with session {} ({})", I(userId), I(contextId), session.getSessionID(), session.getClient(), new Throwable("Dovecot start listener trace"));
@@ -156,7 +156,7 @@ public class StatelessDovecotPushManagerService extends AbstractDovecotPushManag
 
         RegistrationContext registrationContext = getRegistrationContext(pushUser);
         StatelessDovecotPushListener listener = new StatelessDovecotPushListener(registrationContext, false, services);
-        String reason = listener.initateRegistration();
+        String reason = listener.initateRegistration(true);
         if (null == reason) {
             if (LOGGER.isDebugEnabled()) {
                 LOGGER.info("Started permanent Dovecot listener for user {} in context {}", I(userId), I(contextId), new Throwable("Dovecot start permanent listener trace"));
